@@ -22,21 +22,19 @@
 
 #include <KCModule>
 #include <QVariant>
-namespace PimCommon
-{
+namespace PimCommon {
 class ConfigurePluginsWidget;
 }
 
-namespace Akregator
-{
+namespace Akregator {
 class KCMAkregatorPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
     KCMAkregatorPluginsConfig(QWidget *parent, const QVariantList &args);
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 private Q_SLOTS:
     void slotConfigChanged();
 private:
