@@ -32,14 +32,11 @@
 #include <QSharedPointer>
 #include <vector>
 
-namespace Akregator
-{
-
+namespace Akregator {
 class Article;
 class TreeNode;
 
-namespace Filters
-{
+namespace Filters {
 class AbstractMatcher;
 }
 
@@ -73,23 +70,23 @@ public:
     explicit ArticleModel(const QVector<Article> &articles, QObject *parent = nullptr);
     ~ArticleModel();
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    QVariant headerData(int section, Qt::Orientation, int role) const Q_DECL_OVERRIDE;
+    QVariant headerData(int section, Qt::Orientation, int role) const override;
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     bool rowMatches(int row, const QSharedPointer<const Akregator::Filters::AbstractMatcher> &matcher) const;
 
     Article article(int row) const;
 
-    QStringList mimeTypes() const Q_DECL_OVERRIDE;
+    QStringList mimeTypes() const override;
 
-    QMimeData *mimeData(const QModelIndexList &indexes) const Q_DECL_OVERRIDE;
+    QMimeData *mimeData(const QModelIndexList &indexes) const override;
 
-    Qt::ItemFlags flags(const QModelIndex &idx) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &idx) const override;
 
 public Q_SLOTS:
 
@@ -105,7 +102,6 @@ private:
     class Private;
     Private *const d;
 };
-
 } //namespace Akregator
 
 #endif // AKREGATOR_ARTICLEMODEL_H
