@@ -23,8 +23,7 @@
 #include "articleformatter.h"
 #include "akregator_export.h"
 class QPaintDevice;
-namespace Akregator
-{
+namespace Akregator {
 class GrantleeViewFormatter;
 class AKREGATOR_EXPORT DefaultNormalViewFormatter : public ArticleFormatter
 {
@@ -33,9 +32,9 @@ public:
     explicit DefaultNormalViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device = nullptr);
     ~DefaultNormalViewFormatter();
 
-    QString formatArticles(const QVector<Article> &article, IconOption option) const Q_DECL_OVERRIDE;
+    QString formatArticles(const QVector<Article> &article, IconOption option) const override;
 
-    QString formatSummary(TreeNode *node) const Q_DECL_OVERRIDE;
+    QString formatSummary(TreeNode *node) const override;
 
 private:
     DefaultNormalViewFormatter();
