@@ -24,11 +24,10 @@
 using namespace Akregator;
 
 DownloadArticleJob::DownloadArticleJob(QObject *parent)
-    : QObject(parent),
-      mTemporaryFile(nullptr),
-      mAttachmentTemporaryFile(nullptr)
+    : QObject(parent)
+    , mTemporaryFile(nullptr)
+    , mAttachmentTemporaryFile(nullptr)
 {
-
 }
 
 DownloadArticleJob::~DownloadArticleJob()
@@ -77,8 +76,8 @@ void DownloadArticleJob::slotUrlSaveResult(KJob *job)
 {
     if (job->error()) {
         KIO::Job *kiojob = dynamic_cast<KIO::Job *>(job);
-        if (kiojob && kiojob->ui()) {
-            kiojob->ui()->showErrorMessage();
+        if (kiojob && kiojob->uiDelegate()) {
+            kiojob->uiDelegate()->showErrorMessage();
         } else {
             qCWarning(AKREGATOR_LOG) << "There is no GUI delegate set for a kjob, and it failed with error:" << job->errorString();
         }
